@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: texmath
 version: 0.8.4.2
-id: texmath-0.8.4.2-ccfec5cfdf10857fee202173f09a2145
-key: texma_ECtQXwYNPzq8LqNSKRCA2C
+id: texmath-0.8.4.2-95b9676eaa98fd2fb1342251ae775789
+key: texma_8iDnsSN0MJlKQeDYjCDIMd
 license: GPL
 maintainer: jgm@berkeley.edu
 stability: Experimental
@@ -59,12 +59,12 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/texmath-0.8.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/texmath-0.8.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/texmath-0.8.4.2
-hs-libraries: HStexmath-0.8.4.2-ECtQXwYNPzq8LqNSKRCA2C
+hs-libraries: HStexmath-0.8.4.2-8iDnsSN0MJlKQeDYjCDIMd
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    pandoc-types-1.16.1-9cbefa89bd6c10e54a0cf57a0b477515
+    pandoc-types-1.16.1-74c09beb27b9195d9251808dae5f45b7
     parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
     xml-1.3.14-47d6d03c8a900e03cf8951206101564b
